@@ -4,6 +4,12 @@
 #'   * The structure must be like [sda].
 #'   * The column `sector` must have a single value (e.g. "cement").
 #'   * (Optional) If present, the column `label` is used for data labels.
+#' @param span_5yr Logical. Use `TRUE` to restrict the time span to 5 years from
+#'   the start year (the default behavior of `qplot_emission_intensity()`), or use
+#'   `FALSE` to impose no restriction.
+#' @template convert_label
+#' @templateVar fun qplot_emission_intensity
+#' @templateVar value to_title
 #'
 #' @seealso [sda].
 #'
@@ -14,14 +20,28 @@
 #' # `data` must meet documented "Requirements"
 #' data <- subset(sda, sector == "cement")
 #' plot_emission_intensity(data)
-plot_emission_intensity <- function(data) {
-  check_plot_emission_intensity(data)
+#'
+#' # plot with `qplot_emission_intensity()` parameters
+#' plot_emission_intensity(
+#'   data,
+#'   span_5yr = TRUE,
+#'   convert_label = to_title
+#' )
+plot_emission_intensity <- function(data,
+                                    span_5yr = FALSE,
+                                    convert_label = identity) {
+  env <- list(data = substitute(data))
+  check_plot_emission_intensity(data, env = env)
 
-  prep <- prep_emission_intensity(data)
-  plot_emission_intensity_impl(prep)
+  data %>%
+    prep_emission_intensity(
+      convert_label = convert_label,
+      span_5yr = span_5yr
+    ) %>%
+    plot_emission_intensity_impl()
 }
 
-check_plot_emission_intensity <- function(data, env = parent.frame()) {
+check_plot_emission_intensity <- function(data, env) {
   stopifnot(is.data.frame(data))
   crucial <- c("sector", "year", glue("emission_factor_{c('metric', 'value')}"))
   hint_if_missing_names(abort_if_missing_names(data, crucial), "sda")
@@ -33,7 +53,9 @@ check_plot_emission_intensity <- function(data, env = parent.frame()) {
   invisible(data)
 }
 
-prep_emission_intensity <- function(data, convert_label = identity, span_5yr = FALSE) {
+prep_emission_intensity <- function(data,
+                                    convert_label = identity,
+                                    span_5yr = FALSE) {
   out <- data %>%
     prep_common() %>%
     mutate(label = convert_label(.data$label))
@@ -44,7 +66,7 @@ prep_emission_intensity <- function(data, convert_label = identity, span_5yr = F
 
   out <- out %>%
     mutate(
-      year = lubridate::make_date(.data$year)
+      year = as.Date(ISOdate(year = .data$year, month = 1L, day = 1L))
     )
 
   metrics <- distinct(out, .data$emission_factor_metric)
