@@ -10,10 +10,6 @@ test_that("outputs the expected snapshot", {
   })
 })
 
-test_that("technology_colours has `label`", {
-  expect_true(rlang::has_name(technology_colours, "label"))
-})
-
 test_that("scenario_colours has five rows", {
   # Requirement of get_ordered_scenario_colours()
   expect_equal(nrow(scenario_colours), 5L)
